@@ -364,7 +364,7 @@ bool KXsldbgPart::checkDebugger()
 
 void KXsldbgPart::lookupSystemID( QString systemID)
 {
-   bool ok = FALSE;
+   bool ok = false;
    if (!checkDebugger())
      return;
 
@@ -383,12 +383,12 @@ void KXsldbgPart::lookupSystemID( QString systemID)
 			      mainView);
 #endif
    }else{
-     ok = TRUE;
+     ok = true;
    }
   if ( ok && !systemID.isEmpty() ){
       // user entered something and pressed ok
 	QString msg(QString("system %1").arg(systemID));  // noTr
-	debugger->fakeInput(msg, TRUE);
+	debugger->fakeInput(msg, true);
   }
 
 }
@@ -396,7 +396,7 @@ void KXsldbgPart::lookupSystemID( QString systemID)
 
 void KXsldbgPart::lookupPublicID(QString publicID)
 {
-   bool ok = FALSE;
+   bool ok = false;
    if (!checkDebugger())
      return;
 
@@ -413,12 +413,12 @@ void KXsldbgPart::lookupPublicID(QString publicID)
 			      QLineEdit::Normal, QString::null, &ok, mainView );
 #endif
    }else{
-     ok = TRUE;
+     ok = true;
    }
    if ( ok && !publicID.isEmpty()){
      // user entered something and pressed ok
 	QString msg(QString("public %1").arg(publicID));  // noTr
-	debugger->fakeInput(msg, TRUE);
+	debugger->fakeInput(msg, true);
   }
 }
 
@@ -542,14 +542,14 @@ void KXsldbgPart::nextCmd_activated()
 void KXsldbgPart::stepupCmd_activated()
 {
     if ( checkDebugger() )
-      debugger->fakeInput("stepup", TRUE);  // noTr
+      debugger->fakeInput("stepup", true);  // noTr
 }
 
 
 void KXsldbgPart::stepdownCmd_activated()
 {
     if ( checkDebugger() )
-      debugger->fakeInput("stepdown", TRUE);  // noTr
+      debugger->fakeInput("stepdown", true);  // noTr
 }
 
 
@@ -570,7 +570,7 @@ void
 KXsldbgPart::outputCmd_activated()
 {
   if ( ( inspector != 0L ) &&  checkDebugger() && ( configWidget != 0L ) ){
-    debugger->setOutputFileActive(TRUE);
+    debugger->setOutputFileActive(true);
     lineNoChanged( configWidget->getOutputFile(), 1, false );
     refreshCmd_activated();
   }
@@ -588,7 +588,7 @@ void KXsldbgPart::refreshCmd_activated()
      ++it;
     }
     if ( checkDebugger() ){
-	debugger->fakeInput("showbreak", TRUE);  // noTr
+	debugger->fakeInput("showbreak", true);  // noTr
     }
   }
 }
