@@ -62,7 +62,7 @@ CVSService::CVSService(KActionCollection *ac)
   m_menu->insertSeparator();
   action = new KAction(i18n("&Add to Repository..."), "vcs_add", 0, this, SLOT(slotAdd()), ac, "vcs_add");
   action->plug(m_menu);
-  action = new KAction(i18n("&Remove from Repository..."), "vcs_remove", 0, this, SLOT(slotRemove()), ac, "vcs_remove");
+  action = new KAction(i18n("&Remove From Repository..."), "vcs_remove", 0, this, SLOT(slotRemove()), ac, "vcs_remove");
   action->plug(m_menu);
   action = new KAction(i18n("&Ignore in CVS Operations"), 0, this, SLOT(slotAddToCVSIgnore()), ac);
   action->plug(m_menu);
@@ -330,7 +330,7 @@ void CVSService::slotAdd()
 void CVSService::slotAdd(const QStringList &files)
 {
   startService(); 
-  if (m_repository && !m_appId.isEmpty() && (KMessageBox::questionYesNoList(0, i18n("Add the following files to repository?"), files, i18n("CVS Add")) == KMessageBox::Yes))
+  if (m_repository && !m_appId.isEmpty() && (KMessageBox::questionYesNoList(0, i18n("Add the following files to repository?"), files, i18n("CVS Add"), KStdGuiItem::add(), i18n("Do Not Add")) == KMessageBox::Yes))
   {
     emit clearMessages();
     emit showMessage(i18n("Adding file to the repository...") + "\n", false);
