@@ -45,7 +45,7 @@ QuantaPluginInterface::QuantaPluginInterface(QWidget *parent)
                         this, SLOT( slotPluginsEdit() ),
                         ((KMainWindow*)parent)->actionCollection(), "configure_plugins" );
   m_pluginMenu = 0L;
-  // m_plugins.setAutoDelete(TRUE);
+  // m_plugins.setAutoDelete(true);
 }
 
 QuantaPluginInterface::~QuantaPluginInterface()
@@ -171,7 +171,7 @@ void QuantaPluginInterface::writeConfig()
 }
 
 
-/** Returns TRUE if the plugin is available */
+/** Returns true if the plugin is available */
 bool QuantaPluginInterface::pluginAvailable(const QString &a_name)
 {
   if (a_name.isEmpty())
@@ -208,7 +208,7 @@ QuantaPlugin *QuantaPluginInterface::plugin(const QString &a_name)
 void QuantaPluginInterface::buildPluginMenu()
 {
   m_pluginMenu->clear();
-//  m_pluginMenu->setCheckable(TRUE);
+//  m_pluginMenu->setCheckable(true);
 
   QDictIterator<QuantaPlugin> it(m_plugins);
   for(;it.current() != 0;++it)
@@ -218,7 +218,7 @@ void QuantaPluginInterface::buildPluginMenu()
        {
 //         int id = m_pluginMenu->insertItem(curPlugin->pluginName());
 //         if(curPlugin->isRunning())
-//           m_pluginMenu->setItemChecked(id, TRUE);
+//           m_pluginMenu->setItemChecked(id, true);
            curPlugin->plugAction(m_pluginMenu);
        }
   }
@@ -257,7 +257,7 @@ void QuantaPluginInterface::slotPluginsValidate()
      {
          invalidNames += "<br>" + invalidPlugins[i]->name();
      }
-     int answer = KMessageBox::questionYesNo(m_parent, i18n("<qt>The following plugins seems to be invalid:<b>%1</b>.<br><br>Do you want to edit the plugins?</qt>").arg(invalidNames), i18n("Invalid Plugins"));
+     int answer = KMessageBox::questionYesNo(m_parent, i18n("<qt>The following plugins seems to be invalid:<b>%1</b>.<br><br>Do you want to edit the plugins?</qt>").arg(invalidNames), i18n("Invalid Plugins"), i18n("Edit Plugins"), i18n("Do Not Edit"));
       if(answer == KMessageBox::Yes)
       {
         slotPluginsEdit();
