@@ -63,7 +63,7 @@
 #include "viewmanager.h"
 
 ProjectPrivate::ProjectPrivate(Project *p)
-          : QObject(), config(0L), m_dirWatch(0L), tempFile(0L)
+          : QObject(), config(0L), m_dirWatch(0L), tempFile(0L), sessionTempFile(0L)
 {
   parent = p;
   m_projectFiles.setAutoDelete(true);
@@ -107,7 +107,7 @@ void ProjectPrivate::initActions(KActionCollection *ac)
                         ac, "project_view_open" );
   connect(openPrjViewAction, SIGNAL(activated(const QString &)),
           this, SLOT(slotOpenProjectView(const QString &)));
-  openPrjViewAction->setToolTip(i18n("Open Project View"));
+  openPrjViewAction->setToolTip(i18n("Open project view"));
 
   savePrjViewAction = new KAction( i18n( "&Save Project View" ), "filesave", 0,
                         this, SLOT( slotSaveProjectView() ),
@@ -119,7 +119,7 @@ void ProjectPrivate::initActions(KActionCollection *ac)
                         ac, "project_view_delete" );
   connect(deletePrjViewAction, SIGNAL(activated(const QString &)),
           this, SLOT(slotDeleteProjectView(const QString &)));
-  deletePrjViewAction->setToolTip(i18n("Close Project View"));
+  deletePrjViewAction->setToolTip(i18n("Close project view"));
 
 
 
@@ -221,6 +221,8 @@ void ProjectPrivate::init()
   usePreviewPrefix = false;  
   previewPrefix = KURL();
   m_persistentBookmarks = false;
+  m_debuggerPersistentBreakpoints = false;
+  m_debuggerPersistentWatches = false;
   m_excludeCvsignore = false;
   currentProjectView = QString::null;
   m_projectFiles.clear();
@@ -248,7 +250,7 @@ void ProjectPrivate::openCurrentView()
     if (el.attribute("name") == currentProjectView)
     {
       QDomNodeList itemNodes = el.childNodes();
-      for (int j = itemNodes.count()-1; j >= 0 ; j--)
+      for (uint j = 0; j < itemNodes.count(); j++)
       {
         QDomElement el2 = itemNodes.item(j).cloneNode().toElement();
         KURL url = baseURL;
@@ -361,7 +363,7 @@ void ProjectPrivate::insertFiles(const KURL& pathURL, const QString& mask )
   KURL::List list;
 
   list.append(pathURL);
-  list += QExtFileInfo::allFiles( pathURL, mask );
+  list += QExtFileInfo::allFiles(pathURL, mask, m_mainWindow);
   insertFiles(list);
 }
 
@@ -386,13 +388,34 @@ void ProjectPrivate::loadProjectXML()
   }
 
   m_modified = false;
-  QString tmpString = projectNode.toElement().attribute("previewPrefix");
-  if ( !tmpString.isEmpty())
+  QString tmpString;
+  QDomNode sessionNode;
+
+  if (!m_createSessionDom)
   {
-    previewPrefix = KURL::fromPathOrURL( tmpString );
+    sessionNode = m_sessionDom.firstChild().firstChild();
+    tmpString = sessionNode.toElement().attribute("previewPrefix");
+    if ( !tmpString.isEmpty())
+    {
+      previewPrefix = KURL::fromPathOrURL(tmpString);
+    }
+    usePreviewPrefix = ( sessionNode.toElement().attribute("usePreviewPrefix") == "1");
+    m_persistentBookmarks = (sessionNode.toElement().attribute("usePersistentBookmarks") == "1");
+  } else //TODO: Remove when upgrade from 3.4 is not supported
+  {
+    tmpString = projectNode.toElement().attribute("previewPrefix");
+    if ( !tmpString.isEmpty())
+    {
+      previewPrefix = KURL::fromPathOrURL(tmpString);
+    }
+    usePreviewPrefix = ( projectNode.toElement().attribute("usePreviewPrefix") == "1");
+    m_persistentBookmarks = (projectNode.toElement().attribute("usePersistentBookmarks") == "1");
+
+    sessionNode = m_sessionDom.firstChild().firstChild();
+    sessionNode.toElement().setAttribute("usePreviewPrefix", usePreviewPrefix ? "1" : "0");
+    sessionNode.toElement().setAttribute("previewPrefix", previewPrefix.url());
+    sessionNode.toElement().setAttribute("usePersistentBookmarks", m_persistentBookmarks ? "1" : "0");
   }
-  usePreviewPrefix = ( projectNode.toElement().attribute("usePreviewPrefix") == "1");
-  m_persistentBookmarks = (projectNode.toElement().attribute("usePersistentBookmarks") == "1");
   m_eventsEnabled = projectNode.toElement().attribute("enableEvents", "true") == "true";
   m_defaultEncoding = projectNode.toElement().attribute("encoding");
   if (m_defaultEncoding.isEmpty())
@@ -418,6 +441,8 @@ void ProjectPrivate::loadProjectXML()
   // Debugger
   no = projectNode.namedItem("debuggerclient");
   debuggerClient = no.firstChild().nodeValue();
+  m_debuggerPersistentBreakpoints = (no.toElement().attribute("persistentBreakpoints") == "1");
+  m_debuggerPersistentWatches = (no.toElement().attribute("persistentWatches") == "1");
 
   no = projectNode.namedItem("templates");
   tmpString = no.firstChild().nodeValue();
@@ -524,6 +549,7 @@ void ProjectPrivate::loadProjectXML()
       if (f.open(IO_ReadOnly))
       {
         QTextStream stream(&f);
+        stream.setEncoding(QTextStream::UnicodeUTF8);
         QString line;
         while (!stream.atEnd())
         {
@@ -580,6 +606,7 @@ void ProjectPrivate::loadProjectXML()
   if (!no.isNull())
   {
      m_teamLeader.name = no.namedItem("name").toElement().text();
+     m_teamLeader.nickName = no.namedItem("nickName").toElement().text();
      m_teamLeader.email = no.namedItem("email").toElement().text();
   }
 
@@ -593,6 +620,7 @@ void ProjectPrivate::loadProjectXML()
      QDomElement el2 = el.namedItem("subprojectleader").toElement();
      TeamMember member;
      member.name = el2.attribute("name");
+     member.nickName = el2.attribute("nickName");
      member.email = el2.attribute("email");
      SubProject subproject;
      subproject.name = el.attribute("name");
@@ -609,6 +637,7 @@ void ProjectPrivate::loadProjectXML()
      el = nl.item(i).toElement();
      TeamMember member;
      member.name = el.attribute("tasklead");
+     member.nickName = el.attribute("nickName");
      member.email = el.attribute("email");
      m_taskLeaders[el.attribute("task")] = member;
   }
@@ -620,6 +649,7 @@ void ProjectPrivate::loadProjectXML()
      el = nl.item(i).toElement();
      TeamMember member;
      member.name = el.namedItem("name").toElement().text();
+     member.nickName = el.namedItem("nickName").toElement().text();
      member.email = el.namedItem("email").toElement().text();
      member.task = el.attribute("task");
      m_simpleMembers.append(member);
@@ -627,17 +657,40 @@ void ProjectPrivate::loadProjectXML()
 
   no = teamNode.namedItem("mailinglist");
   m_mailingList = no.toElement().attribute("address");
+  teamNode = m_sessionDom.firstChild().namedItem("teamdata");
+  m_yourself = teamNode.toElement().attribute("yourself");
 
   if (m_projectFiles.readFromXML(dom, baseURL, templateURL, excludeRx))
    m_modified = true;
-  QDomElement uploadEl = projectNode.namedItem("uploadprofiles").toElement();
+  QDomNode uploadNode;
+  if (!m_createSessionDom)
+  {
+    uploadNode = sessionNode.namedItem("uploadprofiles");
+  } else
+  {
+    uploadNode = projectNode.namedItem("uploadprofiles").cloneNode(true);
+    sessionNode.appendChild(uploadNode);
+  }
+  
+  QDomElement uploadEl = uploadNode.toElement();
   m_showUploadTreeviews = uploadEl.attribute("showtreeviews", "true") == "true";
   if (m_showUploadTreeviews)
   {
     // read the profiles and create treeviews for them
-    UploadProfiles::ref()->readFromXML(dom);
+    UploadProfiles::ref()->readFromXML(m_sessionDom);
   } else
     UploadProfiles::ref()->clear();
+
+  if (m_createSessionDom)
+  {
+    QDomNode node;
+    node = projectNode.namedItem("treestatus").cloneNode(true);
+    sessionNode.appendChild(node);
+    node = projectNode.namedItem("debuggers").cloneNode(true);
+    sessionNode.appendChild(node);
+  }
+ 
+  
   parent->statusMsg(QString::null);
   parent->newProjectLoaded(projectName, baseURL, templateURL);
   parent->reloadTree(&(m_projectFiles), true, treeStatusFromXML());
@@ -673,7 +726,7 @@ void ProjectPrivate::slotAcceptCreateProject()
   if (baseURL.protocol() == i18n("Local")) baseURL.setProtocol("file");
   baseURL.adjustPath(1);
   if (!baseURL.path().startsWith("/")) baseURL.setPath("/"+ baseURL.path());
-  if (!QExtFileInfo::createDir( baseURL ))
+  if (!QExtFileInfo::createDir(baseURL, m_mainWindow))
   {
     QuantaCommon::dirCreationError(m_mainWindow, baseURL);
     baseURL = oldBaseURL;
@@ -699,9 +752,11 @@ void ProjectPrivate::slotAcceptCreateProject()
       el = dom.firstChild().firstChild().toElement();
       el.setAttribute("type", png->type());
       el.setAttribute("name", projectName );
+      el.setAttribute("encoding", m_defaultEncoding);
+
+      el = m_sessionDom.firstChild().firstChild().toElement();
       el.setAttribute("previewPrefix", previewPrefix.url() );
       el.setAttribute("usePreviewPrefix",usePreviewPrefix);
-      el.setAttribute("encoding", m_defaultEncoding);
 
       el = dom.createElement("author");
       dom.firstChild().firstChild().appendChild( el );
@@ -756,7 +811,7 @@ void ProjectPrivate::slotAcceptCreateProject()
       QuantaCommon::setUrl(templateURL, png->linePrjTmpl->text());
       templateURL.adjustPath(1);
       templateURL = QExtFileInfo::toAbsolute(templateURL, baseURL);
-      if (!QExtFileInfo::createDir(templateURL))
+      if (!QExtFileInfo::createDir(templateURL, m_mainWindow))
       {
         QuantaCommon::dirCreationError(m_mainWindow, templateURL);
       }
@@ -771,7 +826,7 @@ void ProjectPrivate::slotAcceptCreateProject()
     QuantaCommon::setUrl(toolbarURL,png->linePrjToolbar->text());
     toolbarURL.adjustPath(1);
     toolbarURL = QExtFileInfo::toAbsolute(toolbarURL, baseURL);
-    if (!QExtFileInfo::createDir(toolbarURL))
+    if (!QExtFileInfo::createDir(toolbarURL, m_mainWindow))
     {
       QuantaCommon::dirCreationError(m_mainWindow, toolbarURL);
     }
@@ -783,7 +838,11 @@ void ProjectPrivate::slotAcceptCreateProject()
     m_projectFiles.readFromXML(dom, baseURL, templateURL, excludeRx);
     parent->reloadTree( &(m_projectFiles), true, QStringList() );
     saveProject();
+#if KDE_IS_VERSION(3,4,89)
+    m_projectRecent->addURL(projectURL, projectName);
+#else
     m_projectRecent->addURL(projectURL);
+#endif
     m_projectRecent->setCurrentItem(0);
     // remember the project in config
     writeConfig();
@@ -843,8 +902,8 @@ void ProjectPrivate::slotSaveAsProjectView(bool askForName)
     if (node.toElement().attribute("name") == currentProjectView)
     {
       if (!askForName ||
-          KMessageBox::warningYesNo(m_mainWindow, i18n("<qt>A project view named <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>")
-                                            .arg(currentProjectView)) == KMessageBox::Yes)
+          KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>A project view named <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>")
+                                            .arg(currentProjectView), QString::null, i18n("Overwrite")) == KMessageBox::Continue)
       {
         node.parentNode().removeChild(node);
         break;
@@ -909,6 +968,23 @@ bool ProjectPrivate::createEmptyDom()
   stream << "\t</project>" << endl;
   stream << "</webproject>" << endl;
 
+  QString sessionStr;
+  QTextStream sessionStream(&sessionStr, IO_WriteOnly);
+  sessionStream.setEncoding(QTextStream::UnicodeUTF8);
+
+  sessionStream << "<!DOCTYPE webprojectsession ><webprojectsession>" << endl;
+  sessionStream << "\t<session>" << endl;
+  sessionStream << "\t</session>" << endl;
+  sessionStream << "</webprojectsession>" << endl;
+
+  KURL sessionURL = projectURL;
+  QString fileName = projectURL.fileName();
+  if (fileName.endsWith(".webprj"))
+    fileName.replace(".webprj", ".session");
+  else
+    fileName += ".session";
+  sessionURL.setFileName(fileName);
+
   bool result = true;
 
   if (!projectURL.isLocalFile())
@@ -918,11 +994,20 @@ bool ProjectPrivate::createEmptyDom()
     tempFile->textStream()->setEncoding(QTextStream::UnicodeUTF8);
     *(tempFile->textStream()) << str;
     tempFile->close();
-    result = QExtFileInfo::createDir(baseURL);
+    result = QExtFileInfo::createDir(baseURL, m_mainWindow);
     if (result)
       result = KIO::NetAccess::upload(tempFile->name(), projectURL, m_mainWindow);
     if (result)
       m_tmpProjectFile = tempFile->name();
+
+    sessionTempFile = new KTempFile(tmpDir); // sessionTempFile will get deleted in slotProjectClose()
+    sessionTempFile->setAutoDelete(true);
+    sessionTempFile->textStream()->setEncoding(QTextStream::UnicodeUTF8);
+    *(sessionTempFile->textStream()) << sessionStr;
+    sessionTempFile->close();
+    result = KIO::NetAccess::upload(sessionTempFile->name(), sessionURL, m_mainWindow);
+    if (result)
+      m_tmpSessionFile= sessionTempFile->name();
   } else
   {
     QFile f(projectURL.path());
@@ -937,6 +1022,21 @@ bool ProjectPrivate::createEmptyDom()
       result = false;
     }
     f.close();
+    if (result)
+    {
+      f.setName(sessionURL.path());
+      if (f.open(IO_WriteOnly))
+      {
+        QTextStream fstream(&f);
+        fstream.setEncoding(QTextStream::UnicodeUTF8);
+        fstream << sessionStr;
+        m_tmpSessionFile = sessionURL.path();  // we are local: the temp file and the projectURL are the same
+      } else
+      {
+        result = false;
+      }
+      f.close();
+    }
   }
 
   if (!result)
@@ -945,10 +1045,13 @@ bool ProjectPrivate::createEmptyDom()
     KMessageBox::sorry(m_mainWindow, i18n("<qt>Cannot open file <b>%1</b> for writing.</qt>").arg(projectURL.prettyURL(0, KURL::StripFileProtocol)));
     delete tempFile;
     tempFile = 0L;
+    delete sessionTempFile;
+    sessionTempFile = 0L;
     return false;
   }
 
-  dom.setContent( str);
+  dom.setContent(str);
+  m_sessionDom.setContent(sessionStr);
   m_projectFiles.clear();
   return true;
 }
@@ -957,7 +1060,7 @@ bool ProjectPrivate::createEmptyDom()
 QStringList ProjectPrivate::treeStatusFromXML()
 {
   QStringList folderList;
-  QDomNodeList nl = dom.elementsByTagName("treestatus");
+  QDomNodeList nl = m_sessionDom.elementsByTagName("treestatus");
   if (nl.count() > 0) {
     nl = nl.item(0).childNodes();
     for ( unsigned int i = 0; i < nl.count(); i++ )
@@ -973,7 +1076,7 @@ QStringList ProjectPrivate::treeStatusFromXML()
 void ProjectPrivate::getStatusFromTree()
 {
   // remove old status
-  QDomNodeList nl = dom.elementsByTagName("treestatus");
+  QDomNodeList nl = m_sessionDom.elementsByTagName("treestatus");
   QDomElement  el;
   for ( unsigned int i = 0; i < nl.count(); i++ )
   {
@@ -989,10 +1092,10 @@ void ProjectPrivate::getStatusFromTree()
      folderList.remove(folderList.begin());
   if (folderList.count() > 0) {
     // create the root element
-    QDomElement root = dom.createElement("treestatus");
-    dom.firstChild().firstChild().appendChild( root );
+    QDomElement root = m_sessionDom.createElement("treestatus");
+    m_sessionDom.firstChild().firstChild().appendChild(root);
     for (QStringList::Iterator it = folderList.begin(); it != folderList.end(); ++it) {
-      el = dom.createElement("openfolder");
+      el = m_sessionDom.createElement("openfolder");
       el.setAttribute("url", QuantaCommon::qUrl( QExtFileInfo::toRelative(KURL(*it), baseURL) ) );
       root.appendChild( el );
     }
@@ -1097,12 +1200,13 @@ void ProjectPrivate::slotProceedWithCloseProject(bool success)
   emit eventHappened("before_project_close", baseURL.url(), QString::null);
   if (!uploadProjectFile())
   {
-    if (KMessageBox::warningYesNo(m_mainWindow, i18n("Saving of project failed. Do you want to continue with closing (might cause data loss)?"), i18n("Project Saving Error")) == KMessageBox::No)
+    if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("Saving of project failed. Do you want to continue with closing (might cause data loss)?"), i18n("Project Saving Error"), KStdGuiItem::close()) == KMessageBox::Cancel)
       return;
   }
   emit eventHappened("after_project_close", baseURL.url(), QString::null);
   // empty dom tree
   dom.clear();
+  m_sessionDom.clear();
   m_events->clear();
   config->setGroup("Projects");
   config->writePathEntry("Last Project", QString::null);
@@ -1156,6 +1260,14 @@ bool ProjectPrivate::saveProject()
     stream.setEncoding(QTextStream::UnicodeUTF8);
     dom.save(stream, 2);
     f.close();
+    f.setName(m_tmpSessionFile);
+    if (f.open(IO_WriteOnly))
+    {
+      QTextStream stream(&f);
+      stream.setEncoding(QTextStream::UnicodeUTF8);
+      m_sessionDom.save(stream, 2);
+      f.close();
+    }
     m_modified = false;
     parent->statusMsg(i18n( "Wrote project file %1" ).arg(m_tmpProjectFile));
   } else
@@ -1168,9 +1280,12 @@ bool ProjectPrivate::saveProject()
 }
 
 
-void ProjectPrivate::loadProjectFromTemp(const KURL &url, const QString &tempFile)
+void ProjectPrivate::loadProjectFromTemp(const KURL &url, const QString &tempFile, const QString &sessionTempFile)
 {
+  m_createSessionDom = true;
   m_tmpProjectFile = tempFile;
+  if (!sessionTempFile.isEmpty())
+    m_tmpSessionFile = sessionTempFile;
   projectURL = url;
   QFile f(tempFile);
   if (f.open(IO_ReadOnly))
@@ -1185,9 +1300,24 @@ void ProjectPrivate::loadProjectFromTemp(const KURL &url, const QString &tempFil
     }
     dom.setContent(&f);
     f.close();
+    if (!sessionTempFile.isEmpty())
+    {
+      f.setName(sessionTempFile);
+      if (f.open(IO_ReadOnly))
+      {
+        m_sessionDom.setContent(&f);
+        m_createSessionDom = false;
+        f.close();
+      }
+    }
     loadProjectXML();
     openCurrentView();
-    m_projectRecent->addURL(url);
+#if KDE_IS_VERSION(3,4,89)
+    kdDebug(24000) << "Add recent project: " << url << " : projectName= " << projectName << endl;
+    m_projectRecent->addURL(url, projectName);
+#else
+    m_projectRecent->addURL( url );
+#endif
     m_projectRecent->setCurrentItem(0);
     // remember the project in config
     writeConfig();
@@ -1212,19 +1342,62 @@ void ProjectPrivate::loadProject(const KURL &url)
   if ( projectAlreadyOpen(url.url()) )
   {
     parent->hideSplash();
-    if (KMessageBox::warningYesNo(m_mainWindow, i18n("<qt>The project<br><b>%1</b><br> seems to be used by another Quanta instance.<br>You may end up with data loss if you open the same project in two instances, modify and save them in both.<br><br>Do you want to proceed with open?</qt>").arg(url.prettyURL())) == KMessageBox::No)
+    if (KMessageBox::warningContinueCancel(m_mainWindow, i18n("<qt>The project<br><b>%1</b><br> seems to be used by another Quanta instance.<br>You may end up with data loss if you open the same project in two instances, modify and save them in both.<br><br>Do you want to proceed with open?</qt>").arg(url.prettyURL()), QString::null, KStdGuiItem::open()) == KMessageBox::Cancel)
       return;
   }
-  QString tmpFile = QString::null;
+  QString projectTmpFile;
+  QString sessionTmpFile;  
+
   // test if url is writeable and download to local file
   if (KIO::NetAccess::exists(url, false, m_mainWindow) &&
-      KIO::NetAccess::download(url, tmpFile, m_mainWindow))
+      KIO::NetAccess::download(url, projectTmpFile, m_mainWindow))
   {
     if (parent->hasProject())
     {
       slotCloseProject();
     }
-    loadProjectFromTemp(url, tmpFile);
+    KURL sessionURL = url;
+    QString fileName = url.fileName();
+    if (fileName.endsWith(".webprj"))
+      fileName.replace(".webprj", ".session");
+    else
+      fileName += ".session";
+    sessionURL.setFileName(fileName);
+    if (KIO::NetAccess::exists(sessionURL, false, m_mainWindow))
+     KIO::NetAccess::download(sessionURL, sessionTmpFile, m_mainWindow);
+    else
+    {
+      QString sessionStr;
+      QTextStream sessionStream(&sessionStr, IO_WriteOnly);
+      sessionStream.setEncoding(QTextStream::UnicodeUTF8);
+    
+      sessionStream << "<!DOCTYPE webprojectsession ><webprojectsession>" << endl;
+      sessionStream << "\t<session>" << endl;
+      sessionStream << "\t</session>" << endl;
+      sessionStream << "</webprojectsession>" << endl;
+      if (!sessionURL.isLocalFile())
+      {
+        sessionTempFile = new KTempFile(tmpDir); // sessionTempFile will get deleted in slotProjectClose()
+        sessionTempFile->setAutoDelete(true);
+        sessionTempFile->textStream()->setEncoding(QTextStream::UnicodeUTF8);
+        *(sessionTempFile->textStream()) << sessionStr;
+        sessionTempFile->close();
+        m_tmpSessionFile = sessionTempFile->name();
+      } else
+      {
+        QFile f(sessionURL.path());
+        if (f.open(IO_WriteOnly))
+        {
+          QTextStream fstream(&f);
+          fstream.setEncoding(QTextStream::UnicodeUTF8);
+          fstream << sessionStr;
+          m_tmpSessionFile = sessionURL.path();  // we are local: the temp file and the projectURL are the same
+        } 
+        f.close();
+      }
+      m_sessionDom.setContent(sessionStr);
+    }
+    loadProjectFromTemp(url, projectTmpFile, sessionTmpFile);
   } else
   {
     parent->hideSplash();
@@ -1311,23 +1484,29 @@ void ProjectPrivate::slotDebuggerOptions()
     KService::Ptr service = *iterDbg;
     if(m_debuggerClientEdit == service->name())
     {
+      DebuggerClient *dbg = dbg;
       int errCode = 0;
-      DebuggerClient::DebuggerClient* dbg = KParts::ComponentFactory::createInstanceFromService<DebuggerClient::DebuggerClient>(service, this, 0, QStringList(), &errCode);
+//Workaround for dynamic_cast not working correctly on SUSE 10, gcc 4.0.2
+//The correct way should be a simple:
+// DebuggerClient *dbg = KParts::ComponentFactory::createInstanceFromService<DebuggerClient>(service, this, 0, QStringList(), &errCode);
+      QObject* obj = KParts::ComponentFactory::createInstanceFromService<QObject>(service, this, 0, QStringList(), &errCode);
+      if (obj && obj->inherits("DebuggerClient"))
+        dbg = static_cast<DebuggerClient *>(obj);
       if (dbg)
       {
-        QDomNode projectNode = dom.firstChild().firstChild();
+        QDomNode projectNode = m_sessionDom.firstChild().firstChild();
         QDomNode nodeThisDbg;
         QDomNode nodeDbg  = projectNode.namedItem("debuggers");
         if(nodeDbg.isNull())
         {
-          nodeDbg = dom.createElement("debuggers");
+          nodeDbg = m_sessionDom.createElement("debuggers");
           projectNode.appendChild(nodeDbg);
         }
 
         nodeThisDbg = nodeDbg.namedItem(service->name());
         if(nodeThisDbg.isNull())
         {
-          nodeThisDbg = dom.createElement(service->name());
+          nodeThisDbg = m_sessionDom.createElement(service->name());
           nodeDbg.appendChild(nodeThisDbg);
         }
         dbg->showConfig(nodeThisDbg);
@@ -1366,6 +1545,9 @@ void ProjectPrivate::writeConfig()
       projectList = config->readPathListEntry("ProjectTempFiles");
       projectList.append(KURL::fromPathOrURL(m_tmpProjectFile).url());
       config->writePathEntry("ProjectTempFiles", projectList);
+      projectList = config->readPathListEntry("ProjectSessionTempFiles");
+      projectList.append(KURL::fromPathOrURL(m_tmpSessionFile).url());
+      config->writePathEntry("ProjectSessionTempFiles", projectList);
     }
   }
   // save recent projects
@@ -1389,6 +1571,12 @@ void ProjectPrivate::removeFromConfig(const QString & urlStr)
     projectList = config->readPathListEntry("ProjectTempFiles");
     projectList.remove(projectList.at(i));
     config->writePathEntry("ProjectTempFiles", projectList);
+    projectList = config->readPathListEntry("ProjectSessionTempFiles");
+    if (projectList.count() > (uint)i)
+    {
+      projectList.remove(projectList.at(i));
+      config->writePathEntry("ProjectSessionTempFiles", projectList);
+    }
   }
   config->sync();
 }
@@ -1408,6 +1596,14 @@ bool ProjectPrivate::uploadProjectFile()
 {
   if (m_tmpProjectFile.isNull() || !saveProject())
     return false;
+  KURL sessionURL = projectURL;
+  QString fileName = projectURL.fileName();
+  if (fileName.endsWith(".webprj"))
+    fileName.replace(".webprj", ".session");
+  else
+    fileName += ".session";
+  sessionURL.setFileName(fileName);
+
   // no need to upload a local file because it is the same as the tempFile
   if (projectURL.isLocalFile())
   {
@@ -1415,10 +1611,12 @@ bool ProjectPrivate::uploadProjectFile()
     // delete all temp files we used
     delete tempFile;
     tempFile = 0L;
+    delete sessionTempFile;
+    sessionTempFile = 0L;
     m_tmpProjectFile = QString::null;
     return true;
   }
-  if (KIO::NetAccess::upload(m_tmpProjectFile, projectURL, m_mainWindow))
+  if (KIO::NetAccess::upload(m_tmpProjectFile, projectURL, m_mainWindow) && KIO::NetAccess::upload(m_tmpSessionFile, sessionURL, m_mainWindow))
   {
     removeFromConfig(projectURL.url());    // remove the project from the list of open projects
     if (quantaApp)
@@ -1427,11 +1625,16 @@ bool ProjectPrivate::uploadProjectFile()
     // first the one from creating a new project
     delete tempFile;
     tempFile = 0L;
+    delete sessionTempFile;
+    sessionTempFile = 0L;
     // second the one from downloading a project
     KIO::NetAccess::removeTempFile(m_tmpProjectFile);
+    KIO::NetAccess::removeTempFile(m_tmpSessionFile);
     // third if we recovered after crash
     KIO::NetAccess::del(KURL().fromPathOrURL(m_tmpProjectFile), m_mainWindow);
-    m_tmpProjectFile = QString::null;
+    KIO::NetAccess::del(KURL().fromPathOrURL(m_tmpSessionFile), m_mainWindow);
+    m_tmpProjectFile = "";
+    m_tmpSessionFile = "";
   }
   else
   {
