@@ -39,6 +39,7 @@
 #include <kactionclasses.h>
 #include <kdialogbase.h>
 #include <kiconloader.h>
+#include <kmdcodec.h>
 #include <kmessagebox.h>
 #include <ktempfile.h>
 #include <kdirwatch.h>
@@ -98,6 +99,7 @@ Document::Document(KTextEditor::Document *doc,
   m_dirty   = false;
   busy    = false;
   changed = false;
+  m_md5sum = "";
   m_doc = doc;
   m_view = 0L; //needed, because createView() calls processEvents() and the "this" may be deleted before m_view gets a value => crash on delete m_view;
   m_view = m_doc->createView(parent, 0L);
@@ -167,6 +169,8 @@ Document::Document(KTextEditor::Document *doc,
   selectionIf = dynamic_cast<KTextEditor::SelectionInterface *>(m_doc);
   selectionIfExt = dynamic_cast<KTextEditor::SelectionInterfaceExt *>(m_doc);
   configIf = dynamic_cast<KTextEditor::ConfigInterface*>(m_doc);
+  if (configIf)
+      configIf->readConfig();
   viewCursorIf = dynamic_cast<KTextEditor::ViewCursorInterface *>(m_view);
   codeCompletionIf = dynamic_cast<KTextEditor::CodeCompletionInterface *>(m_view);
   markIf = dynamic_cast<KTextEditor::MarkInterface *>(m_doc);
@@ -177,11 +181,13 @@ Document::Document(KTextEditor::Document *doc,
     iface->setPixmap(KTextEditor::MarkInterface::markType02, SmallIcon("debug_breakpoint"));
     iface->setDescription(KTextEditor::MarkInterface::markType02, i18n("Breakpoint"));
     iface->setPixmap(KTextEditor::MarkInterface::markType05, SmallIcon("debug_currentline"));
-  }
+    iface->setDescription(KTextEditor::MarkInterface::markType08, i18n("Annotation"));
+    iface->setPixmap(KTextEditor::MarkInterface::markType08, SmallIcon("stamp"));
 
-  // FIXME: This is allows user to set breakpoints and bookmarks by clicking or rightclicking on the icon border. However, it needs some additional code to
-  // work for breakpoints and has been disabled to prevent confusion.
-  //iface->setMarksUserChangable(KTextEditor::MarkInterface::markType01 + KTextEditor::MarkInterface::markType02);
+    // This is allows user to set breakpoints and bookmarks by clicking or rightclicking on the icon border.
+    iface->setMarksUserChangable(KTextEditor::MarkInterface::markType01 + KTextEditor::MarkInterface::markType02);
+
+  }
 
   tempFile = 0;
   m_tempFileName = QString::null;
@@ -211,10 +217,16 @@ Document::Document(KTextEditor::Document *doc,
   connect(m_view, SIGNAL(gotFocus(Kate::View*)), SIGNAL(editorGotFocus()));
 
   connect(fileWatcher, SIGNAL(dirty(const QString&)), SLOT(slotFileDirty(const QString&)));
+
+//   connect(m_doc, SIGNAL(marksChanged()), this, SLOT(slotMarksChanged()));
+  connect(m_doc, SIGNAL(markChanged(KTextEditor::Mark, KTextEditor::MarkInterfaceExtension::MarkChangeAction)), this, SLOT(slotMarkChanged(KTextEditor::Mark, KTextEditor::MarkInterfaceExtension::MarkChangeAction)));
+  
 }
 
 Document::~Document()
 {
+  if (configIf)
+      configIf->writeConfig();
   parser->clearGroups();
   //  kdDebug(24000) << "Document::~ Document: " << this << endl;
   m_doc->closeURL(false); //TODO: Workaround for a Kate bug. Remove when KDE < 3.2.0 support is dropped.
@@ -224,7 +236,7 @@ Document::~Document()
 void Document::setUntitledUrl(const QString &url)
 {
   untitledUrl = url;
-  m_doc->openURL(KURL());
+  openURL(KURL());
 }
 
 bool Document::isUntitled()
@@ -251,7 +263,7 @@ void Document::insertTag(const QString &s1, const QString &s2)
     reparseEnabled = true;
   }
   insertText(s1 + selection);
-  insertText(s2, FALSE); // don't adjust cursor, thereby leaving it in the middle of tag
+  insertText(s2, false); // don't adjust cursor, thereby leaving it in the middle of tag
 }
 
 
@@ -279,22 +291,24 @@ void Document::changeTagNamespace(Tag *tag, const QString& nameSpace)
   if (!tag->nameSpace.isEmpty())
   {
     tag->beginPos(bl, bc);
+    if (tag->type == Tag::XmlTagEnd)
+      bc++;
     tag->namePos(nl, nc);
     reparseEnabled = false;
-    editIf->removeText(bl, bc+1, nl, nc);
+    editIf->removeText(bl, bc + 1, nl, nc);
     reparseEnabled = true;
   } else
   {
     tag->beginPos(bl, bc);
+    if (tag->type == Tag::XmlTagEnd)
+      bc++;
   }
-  if (nameSpace.isEmpty())
+  if (!nameSpace.isEmpty())
   {
-    slotDelayedTextChanged();
-  } else
-  {
-    viewCursorIf->setCursorPositionReal((uint)bl, (uint)(bc+1));
-    insertText(nameSpace+":");
+    viewCursorIf->setCursorPositionReal((uint)bl, (uint)(bc + 1));
+    insertText(nameSpace + ":", true, false);
   }
+  slotDelayedTextChanged(true);
   quantaApp->slotNewLineColumn();
 }
 
@@ -394,9 +408,9 @@ void Document::insertFile(const KURL& url)
     fileName = url.path();
   } else
   {
-    if (!KIO::NetAccess::download(url, fileName, 0))
+    if (!KIO::NetAccess::download(url, fileName, this))
     {
-      KMessageBox::error(0, i18n("<qt>Cannot download <b>%1</b>.</qt>").arg( url.prettyURL(0, KURL::StripFileProtocol)));
+      KMessageBox::error(this, i18n("<qt>Cannot download <b>%1</b>.</qt>").arg( url.prettyURL(0, KURL::StripFileProtocol)));
       return;
     }
   }
@@ -412,8 +426,9 @@ void Document::insertFile(const KURL& url)
 }
 
 /** Inserts text at the current cursor position */
-void Document::insertText(const QString &text, bool adjustCursor, bool reparse)
+void Document::insertText(const QString &a_text, bool adjustCursor, bool reparse)
 {
+  QString text = a_text;
   if(text.isEmpty())
     return;
 
@@ -421,6 +436,22 @@ void Document::insertText(const QString &text, bool adjustCursor, bool reparse)
   unsigned int line, col;
 
   viewCursorIf->cursorPositionReal(&line, &col);
+  Node *n = parser->nodeAt(line, col, true);
+  if (n && n->tag->dtd()->family != Xml)
+  {
+    int bLine, bCol;
+    n->tag->beginPos(bLine, bCol);
+    QString s = this->text(bLine, bCol, line, col);
+    bool insideQuotes = false;
+    for (int i = 0 ; i < (int)s.length() - 1; i++)
+    {
+      if (s[i] == '"' && (i == 0 || s[i-1] != '\\'))
+        insideQuotes = !insideQuotes;
+    }
+    if (insideQuotes)
+      text.replace("\"", "\\\"");
+  }
+
   editIf->insertText(line, col, text);
 
   // calculate new cursor position
@@ -730,16 +761,21 @@ void Document::slotDelayedShowCodeCompletion()
 */
 void Document::slotFilterCompletion( KTextEditor::CompletionEntry *completion ,QString *string )
 {
+  kdDebug(24000) << *string << endl;
+  kdDebug(24000) << completion->userdata << endl;
   int pos = completion->userdata.find("|");
   QString s = completion->userdata.left(pos);
   completion->userdata.remove(0,pos+1);
   string->remove(0, s.length());
+  kdDebug(24000) << *string << endl;
+  kdDebug(24000) << completion->userdata << endl;
   if (completion->type == "charCompletion")
   {
     *string = completion->userdata;
     uint line, col;
     viewCursorIf->cursorPositionReal(&line, &col);
     QString s2 = editIf->textLine(line).left(col);
+    kdDebug(24000) << s2 << endl;
     int pos = s2.findRev('&');
     if (pos != -1)
     {
@@ -747,6 +783,7 @@ void Document::slotFilterCompletion( KTextEditor::CompletionEntry *completion ,Q
       string->remove(s2);
     }
     string->append(";");
+    kdDebug(24000) << *string << endl;
   } else
   if ( completion->type == "attributeValue")
   {
@@ -792,43 +829,40 @@ void Document::slotReplaceChar()
 */
 void Document::slotCharactersInserted(int line, int column, const QString& string)
 {
-  if (qConfig.replaceAccented && encodingIf)
+  if (qConfig.replaceNotInEncoding)
   {
-    QString encoding = encodingIf->encoding();
-    if (encoding != m_encoding)
+    if (encodingIf)
     {
-      m_encoding = encoding;
-      m_codec = QTextCodec::codecForName(encoding);
+      QString encoding = encodingIf->encoding();
+      if (encoding != m_encoding)
+      {
+        m_encoding = encoding;
+        m_codec = QTextCodec::codecForName(encoding);
+      }
+      if (!m_codec->canEncode(string[0]))
+      {
+        m_replaceLine = line;
+        m_replaceCol = column;
+        m_replaceStr = QString("&#%1;").arg(string[0].unicode());
+        QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
+        return;
+      }
     }
-    if (!m_codec->canEncode(string[0]))
+  }
+  if (qConfig.replaceAccented)
+  {
+    uint c = string[0].unicode();
+    if (c > 191)
     {
       m_replaceLine = line;
       m_replaceCol = column;
-      m_replaceStr = QString("&#%1;").arg(string[0].unicode());
+      m_replaceStr = QString("&#%1;").arg(c);
       QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
-      return;    
+      return;
     }
   }
-
   
-//  uint c = string[0].unicode();
-//  if (qConfig.replaceAccented && c > 191)
-//  {
-//     uint ch = replaceCharList[0];
-//     int i = 0;
-//     while (ch != 0)
-//     {
-//         if (c == ch)
-//         {
-//            m_replaceLine = line;
-//            m_replaceCol = column;
-//            m_replaceStr = QString("&#%1;").arg(c);
-//            QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
-//            return;
-//         }
-//         ch = replaceCharList[++i];
-//     }
-//  }
+
  if ( (string == ">") ||
       (string == "<") )
  {
@@ -914,7 +948,7 @@ bool Document::xmlAutoCompletion(int line, int column, const QString & string)
       showCodeCompletions( getTagCompletions(line, column + 1) );
       handled = true;
     } else
-    if (string == ">" && !tagName.isEmpty() && tagName[0] != '!' &&
+    if (string == ">" && !tagName.isEmpty() && tagName[0] != '!' && tagName[0] != '?' &&
         tagName[0] != '/' && !tagName.endsWith("/") && !s.endsWith("/>") &&
         qConfig.closeTags &&
         currentDTD(true)->family == Xml) //close unknown tags
@@ -1722,7 +1756,7 @@ bool Document::scriptAutoCompletion(int line, int column, const QString& inserte
  }
  if ( !handled && !argHintVisible &&
       (completionRequested ||
-       (s[i] == completionDTD->tagAutoCompleteAfter && (insertedString == " " || insertedString[0] == completionDTD->tagAutoCompleteAfter)) ||
+       (s[i] == completionDTD->tagAutoCompleteAfter && (insertedString == " " || (insertedString[0] == completionDTD->tagAutoCompleteAfter && !completionDTD->requestSpaceBeforeTagAutoCompletion))) ||
        completionDTD->tagAutoCompleteAfter == '\1' || (!completionDTD->memberAutoCompleteAfter.pattern().isEmpty() && completionDTD->memberAutoCompleteAfter.searchRev(s) != -1))
        )
  {
@@ -2081,31 +2115,40 @@ void Document::checkDirtyStatus()
     }
     if (m_dirty)
     {
-      //check if the file is changed, also by file content. Might help to reduce
-      //unwanted warning on NFS
-      QFile f(fileName);
-      QFile tmpFile(m_tempFileName);
-      if (f.open(IO_ReadOnly) && tmpFile.open(IO_ReadOnly))
+      if (m_md5sum.isEmpty())
       {
-        QString encoding = quantaApp->defaultEncoding();
-        if (encodingIf)
-          encoding = encodingIf->encoding();
-        if (encoding.isEmpty())
-          encoding = "utf8";  //final fallback
-  
-        QString content;
-        QTextStream stream(&f);
-        stream.setCodec(QTextCodec::codecForName(encoding));
-        content = stream.read();
-        QString tmpContent;
-        QTextStream tmpStream(&tmpFile);
-        tmpStream.setCodec(QTextCodec::codecForName(encoding));
-        tmpContent = tmpStream.read();
-        if (content == tmpContent)
+        QFile f(fileName);
+        if (f.open(IO_ReadOnly))
         {
-          m_dirty = false;
+          const char* c = "";
+          KMD5 context(c);
+          context.reset();
+          context.update(f);
+          m_md5sum = context.hexDigest();
+          f.close();
+        }
+        m_dirty = false;
+      } else
+      {
+        //check if the file is changed, also by file content. Might help to reduce
+        //unwanted warning on NFS
+        QFile f(fileName);
+        if (f.open(IO_ReadOnly))
+        {
+          QString md5sum;
+          const char* c = "";
+          KMD5 context(c);
+          context.reset();
+          context.update(f);
+          md5sum = context.hexDigest();
+          kdDebug(24000) << "MD5 sum of current doc: " << m_md5sum << endl;
+          kdDebug(24000) << "MD5 sum of doc on disc : " << md5sum << endl;
+          if (md5sum == m_md5sum)
+          {
+            m_dirty = false;
+          }
+          f.close();
         }
-        f.close();
       }
     }
     if (m_dirty)
@@ -2121,7 +2164,7 @@ void Document::checkDirtyStatus()
       if (dlg->exec())
       {
           m_doc->setModified(false);
-          m_doc->openURL(url());
+          openURL(url());
       }
       m_modifTime = QFileInfo(fileName).lastModified();
       delete dlg;
@@ -2683,7 +2726,7 @@ void Document::open(const KURL &url, const QString &encoding)
     }
     connect(m_doc, SIGNAL(completed()), this, SLOT(slotOpeningCompleted()));
     connect(m_doc, SIGNAL(canceled(const QString&)), this, SLOT(slotOpeningFailed(const QString&)));
-    if (!m_doc->openURL(url))
+    if (!openURL(url))
       slotOpeningFailed(QString::null);
     if (!url.isLocalFile())
     {
@@ -2716,6 +2759,7 @@ void Document::slotOpeningCompleted()
 
 void Document::slotOpeningFailed(const QString &errorMessage)
 {
+  m_md5sum = "";
   Q_UNUSED(errorMessage); //TODO: append the error message to our own error message
   if (!url().isLocalFile())
     qApp->exit_loop();
@@ -2863,6 +2907,17 @@ void Document::slotFileDirty(const QString& fileName)
   }
 }
 
+void Document::slotMarkChanged(KTextEditor::Mark mark, KTextEditor::MarkInterfaceExtension::MarkChangeAction action)
+{
+  if(mark.type & KTextEditor::MarkInterface::markType02)
+  {
+    if(action == KTextEditor::MarkInterfaceExtension::MarkRemoved)
+      emit breakpointUnmarked(this, mark.line);
+    else
+      emit breakpointMarked(this, mark.line);
+  }
+}
+
 void Document::resetDTEPs()
 {
   m_DTEPList.clear();
@@ -2885,4 +2940,96 @@ QStringList Document::groupsForDTEPs()
     return m_groupsForDTEPs;
 }
 
+QString Document::annotationText(uint line)
+{
+  QMap<uint, QPair<QString, QString> >::Iterator it = m_annotations.find(line);
+  if (it != m_annotations.end())
+    return it.data().first;
+  else
+   return QString::null;
+}
+
+void Document::setAnnotationText(uint line, const QString& text)
+{
+  if (text.isEmpty())
+  {
+    m_annotations.remove(line);
+    if (markIf)
+      markIf->removeMark(line, KTextEditor::MarkInterface::markType08);
+  } else
+  {
+    m_annotations.insert(line, qMakePair(text, QString("")));
+    if (markIf)
+      markIf->setMark(line, KTextEditor::MarkInterface::markType08);
+    uint line, column;
+    viewCursorIf->cursorPositionReal(&line, &column);
+    viewCursorIf->setCursorPositionReal(line, 0);
+    const DTDStruct *dtd = currentDTD(true);
+    QString commentBegin = "";
+    QString commentEnd = "";
+    for (QMap<QString, QString>::ConstIterator it = dtd->comments.constBegin(); it != dtd->comments.constEnd(); ++it)
+    {
+      commentBegin = it.key();
+      commentEnd = it.data();
+      if (commentEnd != "\n")
+        break;
+    }
+    if (commentBegin.isEmpty())
+    {
+      if (dtd->family == Xml)
+      {
+        commentBegin = "<!--";
+        commentEnd = "-->";
+      } else
+      {
+        commentBegin = "/*";
+        commentEnd = "*/";
+      }
+    }
+    QString s = "@annotation: " + text;
+    s.prepend(commentBegin + " ");
+    s.append(" " + commentEnd + "\n");
+    insertText(s, true, true);
+    emit showAnnotation(line, "", qMakePair(text, QString("")));
+  }
+}
+
+void Document::addAnnotation(uint line, const QPair<QString, QString>& annotation)
+{
+  m_annotations.insert(line, annotation);
+  if (markIf)
+    markIf->setMark(line, KTextEditor::MarkInterface::markType08);
+  emit showAnnotation(line, "", annotation);
+}
+
+void Document::clearAnnotations()
+{
+  if (markIf)
+  {
+    QPtrList<KTextEditor::Mark> m = markIf->marks();
+    for (uint i=0; i < m.count(); i++)
+      markIf->removeMark( m.at(i)->line, KTextEditor::MarkInterface::markType08 );
+ }
+ m_annotations.clear();
+}
+
+bool Document::openURL(const KURL& url)
+{
+  m_md5sum = "";
+  if (url.isLocalFile())
+  {
+    QFile f(url.path());
+    if (f.open(IO_ReadOnly))
+    {
+      const char* c = "";
+      KMD5 context(c);
+      context.reset();
+      context.update(f);
+      m_md5sum = context.hexDigest();
+      f.close();
+    }
+  }
+  return m_doc->openURL(url);
+}
+
 #include "document.moc"
