@@ -21,8 +21,12 @@
 //qt includes
 #include <qdatetime.h>
 #include <qdict.h>
+#include <qmap.h>
 #include <qwidget.h>
 
+#include <kurl.h>
+#include <ktexteditor/markinterfaceextension.h>
+
 //own includes
 #include "qtag.h"
 
@@ -30,6 +34,7 @@
   *@author Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon & Andras Mantia
   */
 
+class QDomDocument;
 class QEvent;
 class QFocusEvent;
 class QTextCodec;
@@ -58,6 +63,7 @@ namespace KTextEditor
   class SelectionInterfaceExt;
   class View;
   class ViewCursorInterface;
+  class Mark;
 }
 
 class Document : public QWidget{
@@ -173,6 +179,11 @@ work correctly. */
   QString currentWord();
   /** Opens the url. The url must be valid and the file pointed to it must exists. */
   void open(const KURL &url, const QString &encoding);
+  /**
+   * Opens a file in the editor part.
+   * @param url 
+   */
+  bool openURL(const KURL& url);
   /** Reads the DTD info from the file, tries to find the correct DTD and builds the tag/attribute list from the DTD file. */
   void processDTD(const QString& documentType = QString::null);
 
@@ -214,7 +225,12 @@ work correctly. */
   /** Removes automatic backup copies */
   void removeBackup(KConfig *config);
   /** create a string using document path string */
- static QString hashFilePath(const QString& p);
+  static QString hashFilePath(const QString& p);
+  QString annotationText(uint line);
+  void setAnnotationText(uint line, const QString& text);
+  QMap<uint, QPair<QString, QString> > annotations() {return m_annotations;}
+  void addAnnotation(uint line, const QPair<QString, QString>& annotation);
+  void clearAnnotations();
 
 public slots:
 
@@ -240,7 +256,11 @@ signals:
   void editorGotFocus();
   void openingFailed(const KURL &url);
   void openingCompleted(const KURL &url);
-  
+
+  void breakpointMarked(Document*, int);
+  void breakpointUnmarked(Document*, int);
+  void showAnnotation(uint, const QString&, const QPair<QString, QString>&);
+
 private slots:
   void slotReplaceChar();
   void slotOpeningCompleted();
@@ -248,8 +268,19 @@ private slots:
   /** Called when a file on the disk has changed. */
   void slotFileDirty(const QString& fileName);
 
+  void slotMarkChanged(KTextEditor::Mark mark, KTextEditor::MarkInterfaceExtension::MarkChangeAction action);
 private:
+  /**
+   * Finds the beginning of a tag in the document, starting from a position.
+   * @param position start to look from this position backwards
+   * @return the position of the starting character or an empty QPoint if not found 
+   */
+  QPoint findTagBeginning(const QPoint& position);
+  QPoint findTagEnd(const QPoint& position);
+  
+  
 
+  QMap<uint, QPair<QString, QString> > m_annotations;
   QString untitledUrl;
   int m_replaceLine;
   int m_replaceCol;
@@ -279,6 +310,7 @@ private:
   bool repaintEnabled;
   /** True if the document is dirty (has been modified outside). */
   bool m_dirty;
+  QString m_md5sum;
   Project *m_project;
   /** Parse the document according to this DTD. */
   QStringList m_groupsForDTEPs; ///< The list of the DTEPs for which the groups should appear in the structure tree
