@@ -19,12 +19,15 @@
 #define QUANTA_H
 
 #define QUANTA_PACKAGE "quanta"
-#define QUANTA_VERSION "3.4.2"
+#define QUANTA_VERSION "3.5"
 
 #define IDS_STATUS      1
 #define IDS_INS_OVR     2
 #define IDS_MODIFIED    3
 #define IDS_STATUS_CLM  4
+// Number 5 is used by he debugger, but not added until debugger is activated
+#define IDS_STATUS_DEBUGGER  5  
+
 #define IDS_DEFAULT     "Ready."
 
 // include files for Qt
@@ -74,7 +77,9 @@ class KProcess;
 class KSelectAction;
 class KRecentFilesAction;
 class KToolBarPoupAction;
+class KTextEdit;
 
+class TagAction;
 class Node;
 class Parser;
 class DocTreeView;
@@ -82,6 +87,7 @@ class FilesTreeView;
 class ScriptTreeView;
 class EnhancedTagAttributeTree;
 class Project;
+class AnnotationOutput;
 class MessageOutput;
 class QDomDocument;
 class Document;
@@ -122,6 +128,7 @@ public:
 //TODO: check if we really need these "get" methods (and get rid o get)
   MessageOutput *messageOutput() const {return m_messageOutput;}
   MessageOutput *problemOutput() const {return m_problemOutput;}
+  AnnotationOutput *annotationOutput() const {return m_annotationOutput;}
 
   DebuggerManager *debugger() const {return m_debugger;}
   KParts::PartManager *partManager() {return m_partManager;}
@@ -188,12 +195,25 @@ public:
   void startIdleTimer();
 
   /** Called when a document was closed. Resets some variables. */
-  void slotFileClosed();
+  void slotFileClosed(Document *w);
   void setTabToolTip(QWidget *w, const QString& toolTipStr);
 
   void createPreviewPart();
   void createDocPart();
 
+  /**
+   * This is a pool for actions waiting for being applied (VPL only yet).
+   * For example, whee a user presses the bold action, it isn't immediately applied on the document.
+   * If the user presses a key right away the character is inserted inside the tags for the queued actions.
+   * If the user changes the place of the cursor, the actions waiting for being inserted are removed.
+   */
+  QStringList const& tagActionPool() const {return m_tagActionPool;}
+  void insertTagActionPoolItem(QString const& action_item);
+  void removeTagActionPoolItem(QString const& action_item);
+  void removeAllTagActionPoolItems() {m_tagActionPool.clear();}
+  
+  QPtrList<TagAction> const& tagActions() const {return m_tagActions;}
+
   /** Clicked word or selected text for context sensitive menu in editor */
   QString popupWord;
 
@@ -208,6 +228,9 @@ signals: // Signals
   
   void toolbarRemoved(const QString&);
 
+  void showMessage(const QString&, bool);
+  void clearMessages();
+
 public slots:
   void slotFileNew();
   void slotFileOpen();
@@ -273,6 +296,7 @@ public slots:
 
   void slotShowMessagesView();
   void slotShowProblemsView();
+  void slotShowAnnotationView();
 
   void slotContextMenuAboutToShow();
 
@@ -380,6 +404,8 @@ public slots:
 
   /** Called when the preview or documentation part is deleted. */
   void slotHTMLPartDeleted(QObject *object);
+
+  void slotRefreshActiveWindow();
   
   bool slotEnableIdleTimer(bool enable);
 
@@ -485,6 +511,7 @@ protected slots:
   void slotTabDragged(QWidget *widget);
   void slotTabMoved(int from, int to);
   void slotTabAboutToMove(int from, int to);
+  void slotAnnotate();
 
 protected:
   /** Create a DTEP tarball which can be uploaded or sent in email. Returns
@@ -528,8 +555,10 @@ private:
   /** Message output window */
   MessageOutput *m_messageOutput;
   MessageOutput *m_problemOutput;
+  AnnotationOutput *m_annotationOutput;
   KMdiToolViewAccessor* m_messageOutputView;
   KMdiToolViewAccessor* m_problemsOutputView;
+  KMdiToolViewAccessor* m_annotationOutputView;
   KMdiToolViewAccessor* m_previewToolView;
   KMdiToolViewAccessor* m_documentationToolView;
   Document *m_previewedDocument;
@@ -583,6 +612,9 @@ private:
 
   QString m_scriptOutput;
 
+  QStringList m_tagActionPool;
+  QPtrList<TagAction> m_tagActions;
+
 protected: // Protected attributes
   /** Timer to refresh the structure tree. */
   QTimer *refreshTimer;
