@@ -407,7 +407,7 @@ void BaseTreeView::slotSelectFile(QListViewItem *item)
         }
         else //it is an unknown type, maybe binary
         {
-          if (QuantaCommon::denyBinaryInsert() == KMessageBox::Yes)
+          if (QuantaCommon::denyBinaryInsert(this) == KMessageBox::Yes)
           {
             emit openFile(urlToOpen);
             item->repaint();
@@ -481,24 +481,27 @@ FileInfoDlg* BaseTreeView::addFileInfoPage(KPropertiesDialog* propDlg)
        {
         qfile.open(IO_ReadOnly);
         QString imgname,imgpath;
-        while (qfile.readLine(imgname,200)!=-1)     //open & parse file
+        QTextStream stream(&qfile);
+        stream.setEncoding(QTextStream::UnicodeUTF8);
+        while (!stream.atEnd())     //open & parse file
         {
+          imgname = stream.readLine();
           ct++;
-          position=imgname.find("<img",0,FALSE);              //check for images
+          position=imgname.find("<img",0,false);              //check for images
           if (position!=-1)
           {
             imgname.remove(0,position+4);
-            position=imgname.find("src=",0,FALSE);              //extract images names
+            position=imgname.find("src=",0,false);              //extract images names
             imgname.remove(0,position+4);
             if (imgname.startsWith("\"")) imgname.remove(0,1);
             if (imgname.startsWith("'")) imgname.remove(0,1);
-            position=imgname.find(" ",0,FALSE);
+            position=imgname.find(" ",0,false);
             if (position!=-1) imgname=imgname.left(position);
-            position=imgname.find(">",0,FALSE);
+            position=imgname.find(">",0,false);
             if (position!=-1) imgname=imgname.left(position);
-            position=imgname.find("\"",0,FALSE);
+            position=imgname.find("\"",0,false);
             if (position!=-1) imgname=imgname.left(position);
-            position=imgname.find("'",0,FALSE);
+            position=imgname.find("'",0,false);
             if (position!=-1) imgname=imgname.left(position);
             if (!quantaFileProperties->imageList->findItem(imgname,Qt::ExactMatch))     //check if image was already counted
             {
@@ -718,10 +721,10 @@ void BaseTreeView::slotInsertDirInProject()
 /** Bring up the properites dialog, and extend it for files */
 void BaseTreeView::slotProperties()
 {
-  KURL url = currentURL();
-  if (url.isEmpty()) return;
-  KFileItem fileItem(KFileItem::Unknown, KFileItem::Unknown, url);
-  propDlg = new KPropertiesDialog(&fileItem, this, 0L, false, false); //autodeletes itself
+  if (! currentKFileTreeViewItem()) 
+    return;
+  
+  propDlg = new KPropertiesDialog(currentKFileTreeViewItem()->fileItem(), this, 0L, false, false); //autodeletes itself
   fileInfoDlg = 0L;
   if (!currentKFileTreeViewItem()->isDir())
   {
@@ -1023,9 +1026,9 @@ void BaseTreeView::doRename(KFileTreeViewItem* kftvi, const QString & newName)
   if ( oldURL != newURL )
   {
     bool proceed = true;
-    if (QExtFileInfo::exists(newURL))
+    if (QExtFileInfo::exists(newURL, this))
     {
-      proceed = KMessageBox::warningYesNo(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(newURL.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite")) == KMessageBox::Yes;
+      proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(newURL.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
     }
     if (proceed)
     {
@@ -1146,7 +1149,7 @@ void BaseTreeView::slotCreateSiteTemplate()
    bool error = false;
    if (tar.open(IO_WriteOnly))
    {
-      KURL::List fileList = QExtFileInfo::allFiles(url, "*");
+      KURL::List fileList = QExtFileInfo::allFiles(url, "*", this);
       for (KURL::List::Iterator it = fileList.begin(); it != fileList.end(); ++it)
       {
          if (!(*it).path().endsWith("/"))
@@ -1201,7 +1204,7 @@ void BaseTreeView::slotCreateFile()
       url.setPath(url.path() + "/" + fileName);
     else
       url.setPath(url.directory() + "/" + fileName);
-    if (QExtFileInfo::exists(url))
+    if (QExtFileInfo::exists(url, this))
     {
       KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
       return;
