@@ -243,7 +243,7 @@ void TemplatesTreeView::slotInsertInDocument()
    emit insertFile(url);
  } else
  {
-   if (QuantaCommon::denyBinaryInsert() == KMessageBox::Yes)
+   if (QuantaCommon::denyBinaryInsert(this) == KMessageBox::Yes)
    {
      emit insertFile(url);
    }
@@ -311,7 +311,7 @@ void TemplatesTreeView::slotMenu(KListView*, QListViewItem *item, const QPoint &
 void TemplatesTreeView::slotNewDocument()
 {
  KURL url = filterTemplate();
- if (QuantaCommon::checkMimeGroup(url, "text") || QuantaCommon::denyBinaryInsert() == KMessageBox::Yes)
+ if (QuantaCommon::checkMimeGroup(url, "text") || QuantaCommon::denyBinaryInsert(this) == KMessageBox::Yes)
  {
    QListViewItem *item = currentItem();
    if (item )
@@ -465,9 +465,9 @@ void TemplatesTreeView::contentsDropEvent(QDropEvent *e)
         *(tempFile->textStream()) << content;
         tempFile->close();
         bool proceed = true;
-        if (QExtFileInfo::exists(url))
+        if (QExtFileInfo::exists(url, this))
         {
-          proceed = KMessageBox::warningYesNo(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite")) == KMessageBox::Yes;
+          proceed = KMessageBox::warningContinueCancel(this, i18n("<qt>The file <b>%1</b> already exists.<br>Do you want to overwrite it?</qt>").arg(url.prettyURL(0, KURL::StripFileProtocol)),i18n("Overwrite"), i18n("Overwrite")) == KMessageBox::Continue;
         }
         if (proceed)
         {
@@ -783,7 +783,7 @@ void TemplatesTreeView::slotDragInsert(QDropEvent *e)
    {
      if(m_dirInfo.mimeType == "text/all") // default to inserting in document
      {
-      if(!mimeType.contains("text", false) && QuantaCommon::denyBinaryInsert() != KMessageBox::Yes)
+      if(!mimeType.contains("text", false) && QuantaCommon::denyBinaryInsert(this) != KMessageBox::Yes)
       {
         return;
       }
@@ -798,7 +798,7 @@ void TemplatesTreeView::slotDragInsert(QDropEvent *e)
      else
      if(m_dirInfo.mimeType == "template/all")
      {
-       if(!mimeType.contains("text", false) && QuantaCommon::denyBinaryInsert() != KMessageBox::Yes)
+       if(!mimeType.contains("text", false) && QuantaCommon::denyBinaryInsert(this) != KMessageBox::Yes)
        {
          return;
        }
@@ -923,7 +923,7 @@ KURL TemplatesTreeView::filterTemplate()
    KTempFile* tempFile = new KTempFile(tmpDir);
    filterAction->setOutputFile(tempFile->file());
    filterAction->setInputFileName(url.path());
-   filterAction->execute();
+   filterAction->execute(true);
    filterAction->setOutputFile(0L);
    filterAction->setInputFileName(QString::null);
    tempFile->close();
@@ -953,7 +953,7 @@ QString TemplatesTreeView::createTemplateTarball()
   if ( ! currentKFileTreeViewItem()->isDir() )
     files.append(url);
   else {
-    files = QExtFileInfo::allFiles(dirURL, "*") ;
+    files = QExtFileInfo::allFiles(dirURL, "*", this) ;
     dirURL = dirURL.upURL();
   }
 
@@ -984,14 +984,14 @@ void TemplatesTreeView::slotSendInMail()
 
     TagMailDlg *mailDlg = new TagMailDlg( this, i18n("Send template in email"));
     QString toStr;
-    QString message = i18n("Hi,\n This is a Quanta Plus [http://quanta.sourceforge.net] template tarball.\n\nHave fun.\n");
+    QString message = i18n("Hi,\n This is a Quanta Plus [http://quanta.kdewebdev.org] template tarball.\n\nHave fun.\n");
     QString titleStr;
     QString subjectStr;
 
     mailDlg->TitleLabel->setText(i18n("Content:"));
-    mailDlg->titleEdit->setFixedHeight(60);
+/*    mailDlg->titleEdit->setFixedHeight(60);
     mailDlg->titleEdit->setVScrollBarMode(QTextEdit::Auto);
-    mailDlg->titleEdit->setHScrollBarMode(QTextEdit::Auto);
+    mailDlg->titleEdit->setHScrollBarMode(QTextEdit::Auto);*/
     if ( mailDlg->exec() )
     {
       if ( !mailDlg->lineEmail->text().isEmpty())
@@ -1064,7 +1064,7 @@ void TemplatesTreeView::slotExtractSiteTemplate()
           KIO::NetAccess::removeTempFile(tempFile);
           if (!m_projectBaseURL.isEmpty() && !QExtFileInfo::toRelative(targetURL, m_projectBaseURL).url().startsWith("."))
           {
-             if (KMessageBox::questionYesNo(this, i18n("You have extracted the site template to a folder which is not under your main project folder.\nDo you want to copy the folder into the main project folder?")) == KMessageBox::Yes)
+             if (KMessageBox::questionYesNo(this, i18n("You have extracted the site template to a folder which is not under your main project folder.\nDo you want to copy the folder into the main project folder?"), QString::null, i18n("Copy Folder"), i18n("Do Not Copy")) == KMessageBox::Yes)
              {
                  emit insertDirInProject(targetURL);
              }
