@@ -99,6 +99,7 @@ public:
           bool saveTrees;         ///< save tree status for local trees?
           QMap<QString, Abbreviation> abbreviations; ///< the abbreviation groups
           bool replaceAccented; ///< replace or not the accented characters
+          bool replaceNotInEncoding; ///< replace characters with their entity number if they cannot be saved in the current encoding of the document.
           bool smartTagInsertion; //enable/disable smartTagInsertion
         };
 
@@ -177,7 +178,7 @@ pointer must be deleted by the caller!! */
   static bool closesTag(Tag *tag1, Tag *tag2);
   static bool closesTag(QString namespaceName, QString tagName, bool caseSensitive,
     QString namespaceName2, QString tagName2, bool caseSensitive2);
-  static int denyBinaryInsert();
+  static int denyBinaryInsert(QWidget *window);
   static void removeCommentsAndQuotes(QString& str, const DTDStruct* dtd);
   static bool insideCommentsOrQuotes(int position, const QString &string, const DTDStruct *dtd);
   /** Calls a Quanta DCOP method.
@@ -191,7 +192,7 @@ pointer must be deleted by the caller!! */
   *  @param url the url to check
   *  @return true if the user answered yes, false otherwise.
   */
-  static bool checkOverwrite(const KURL& url);
+  static bool checkOverwrite(const KURL& url, QWidget *window);
 
 };
 
