@@ -92,6 +92,8 @@ public:
 private slots:
   void slotEditAction();
   void slotRemoveAction();
+  void slotIconTextChanged(int id);
+  void slotIconTextMenuAboutToShow();
 
 signals:
   void removeAction(const QString&, const QString&);
